@@ -1,5 +1,5 @@
 /*
-Copyright (C) 1997-2013 Erwin Waterlander
+Copyright (C) 1997-2014 Erwin Waterlander
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -146,6 +146,7 @@ void wcd_printf( const char* format, ... ) {
  * 8 bit characters.
  */
 
+#if (defined(WCD_USECONIO) || defined(WCD_USECURSES))
 size_t str_columns (char *s)
 {
 #if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
@@ -170,6 +171,7 @@ size_t str_columns (char *s)
    return(strlen(s));
 #endif
 }
+#endif
 
 /************************************************************************
  *
@@ -254,7 +256,7 @@ size_t maxLength(nameset list)
 
    if (list == NULL)
    {
-      fprintf(stderr, "%s", _("Wcd: error in maxLength(), list == NULL\n"));
+      print_error("%s", _("internal error in maxLength(), list == NULL\n"));
       return 32 ;
    }
 
@@ -274,7 +276,7 @@ size_t maxLengthStack(WcdStack s)
 
    if (s == NULL)
    {
-      fprintf(stderr, "%s", _("Wcd: error in maxLengthStack(), s == NULL\n"));
+      print_error("%s", _("internal error in maxLengthStack(), s == NULL\n"));
       return 32 ;
    }
 
@@ -427,6 +429,8 @@ int lines_per_page ; /* number of lines to print per page */
 char number_str[WCD_MAX_INPSTR];
 char *buffer;
 struct text_info ti;
+int pageoffset;
+char buf[WCD_MAX_INPSTR];
 
    gettextinfo(&ti);
 
@@ -508,22 +512,24 @@ struct text_info ti;
 
    clrscr();
 
-   cprintf("\n\r");
+   cprintf("\r\n");
    if (list != NULL)
    {
       if(perfect)
-         cprintf("Perfect ");
+         cprintf(_("Perfect match for %d directories."),size);
       else
-         cprintf("Wild ");
-      cprintf("match for %d directories.\n\r",size);
+         cprintf(_("Wild match for %d directories."),size);
    }
-   else
-      cprintf("\n\r");
+   cprintf("\r\n");
 
-   cprintf("Please choose one (<Enter> to abort): ");
+   cprintf(_("Please choose one (<Enter> to abort): "));
    fflush(stdout);
-   gotoxy (PAGEOFFSET, 2);
-   cprintf("w=up x=down ?=help  Page %d/%d      ",page,(size -1)/lines_per_page +1);
+   sprintf(buf,_(" w=up x=down ?=help  Page %d/%d "),page,(size -1)/lines_per_page +1);
+   pageoffset = ti.screenwidth - (int)strlen(buf);
+   if (pageoffset < 0)
+      pageoffset = 0;
+   gotoxy (pageoffset, 2);
+   cprintf("%s",buf);
    gotoxy (OFFSET + n, 3);
 
    while ((c != 13 )&&(( c < 'a' ) || ( c > ('a'+scrollWinHeight-1) || ( c > 'v' ) )))
@@ -594,8 +600,12 @@ struct text_info ti;
          page = bottom / lines_per_page + 1 ;
 
          window (1,scrollWinHeight+1,ti.screenwidth,ti.screenheight);
-         gotoxy (PAGEOFFSET, 2);
-         cprintf("w=up x=down ?=help  Page %d/%d      ",page,(size -1)/lines_per_page +1);
+         sprintf(buf,_(" w=up x=down ?=help  Page %d/%d "),page,(size -1)/lines_per_page +1);
+         pageoffset = ti.screenwidth - (int)strlen(buf);
+         if (pageoffset < 0)
+            pageoffset = 0;
+         gotoxy (pageoffset, 2);
+         cprintf("%s",buf);
          gotoxy (OFFSET + n, 3);
 
 
@@ -622,8 +632,12 @@ struct text_info ti;
          page = bottom / lines_per_page + 1 ;
 
          window (1,scrollWinHeight+1,ti.screenwidth,ti.screenheight);
-         gotoxy (PAGEOFFSET, 2);
-         cprintf("w=up x=down ?=help  Page %d/%d      ",page,(size -1)/lines_per_page +1);
+         sprintf(buf,_(" w=up x=down ?=help  Page %d/%d "),page,(size -1)/lines_per_page +1);
+         pageoffset = ti.screenwidth - (int)strlen(buf);
+         if (pageoffset < 0)
+            pageoffset = 0;
+         gotoxy (pageoffset, 2);
+         cprintf("%s",buf);
          gotoxy (OFFSET + n, 3);
       }/* Page down */
 
@@ -662,22 +676,22 @@ struct text_info ti;
           if (scrollWinHeight < 17)
           {
              gotoxy(1,1);
-             cprintf("Screenheight must be > 20 for help.");
+             cprintf(_("Screenheight must be > 20 for help."));
           }
           else
           {
              gotoxy(1,1);
-             cprintf("w or <Up>         Page Up.\r\n");
-             cprintf("x or z or <Down>  Page Down.\r\n");
-             cprintf(", or <Left>       Scroll 1 left.\r\n");
-             cprintf(". or <Right>      Scroll 1 right.\r\n");
-             cprintf("< or [            Scroll 10 left.\r\n");
-             cprintf("> or ]            Scroll 10 right.\r\n");
-             cprintf("CTRL-a or <HOME>  Scroll to beginning.\r\n");
-             cprintf("CTRL-e or <END>   Scroll to end.\r\n");
-             cprintf("CTRL-c or <Esc>   Abort.\r\n");
-             cprintf("<Enter>           Abort.\r\n");
-             cprintf("Type w or x to quit help.\r\n");
+             cprintf(_("w or <Up>         page up")); cprintf("\r\n");
+             cprintf(_("x or z or <Down>  page down")); cprintf("\r\n");
+             cprintf(_(", or <Left>       scroll 1 left")); cprintf("\r\n");
+             cprintf(_(". or <Right>      scroll 1 right")); cprintf("\r\n");
+             cprintf(_("< or [            scroll 10 left")); cprintf("\r\n");
+             cprintf(_("> or ]            scroll 10 right")); cprintf("\r\n");
+             cprintf(_("CTRL-a or <HOME>  scroll to beginning")); cprintf("\r\n");
+             cprintf(_("CTRL-e or <END>   scroll to end")); cprintf("\r\n");
+             cprintf(_("CTRL-c or <Esc>   abort")); cprintf("\r\n");
+             cprintf(_("<Enter>           abort")); cprintf("\r\n");
+             cprintf(_("Type w or x to quit help.")); cprintf("\r\n");
           }
       }
 
@@ -1125,11 +1139,11 @@ void displayRefresh(int init)
 
    if (wcd_display.list != NULL)
    {
+      wmove (wcd_display.inputWin, 1, 0);
       if(wcd_display.perfect)
-        wcd_mvwaddstr(wcd_display.inputWin,1,0,_("Perfect "));
+         wprintw(wcd_display.inputWin,_("Perfect match for %d directories."),wcd_display.size);
       else
-        wcd_mvwaddstr(wcd_display.inputWin,1,0,_("Wild "));
-      wprintw(wcd_display.inputWin,_("match for %d directories."),wcd_display.size);
+         wprintw(wcd_display.inputWin,_("Wild match for %d directories."),wcd_display.size);
    }
 
    page = wcd_display.bottom / wcd_display.lines_per_page + 1 ;
@@ -1160,16 +1174,16 @@ void displayHelp(WINDOW *win, int height)
       wcd_mvwaddstr(win,0,0,_("Screenheight must be > 20 for help."));
    else
    {
-      wcd_mvwaddstr(win, 0,0,_("w or <Up>         Page Up."));
-      wcd_mvwaddstr(win, 1,0,_("x or z or <Down>  Page Down."));
-      wcd_mvwaddstr(win, 2,0,_(", or <Left>       Scroll 1 left."));
-      wcd_mvwaddstr(win, 3,0,_(". or <Right>      Scroll 1 right."));
-      wcd_mvwaddstr(win, 4,0,_("< or [            Scroll 10 left."));
-      wcd_mvwaddstr(win, 5,0,_("> or ]            Scroll 10 right."));
-      wcd_mvwaddstr(win, 6,0,_("CTRL-a or <HOME>  Scroll to beginning."));
-      wcd_mvwaddstr(win, 7,0,_("CTRL-e or <END>   Scroll to end."));
-      wcd_mvwaddstr(win, 8,0,_("CTRL-c or <Esc>   Abort."));
-      wcd_mvwaddstr(win, 9,0,_("<Enter>           Abort."));
+      wcd_mvwaddstr(win, 0,0,_("w or <Up>         page up"));
+      wcd_mvwaddstr(win, 1,0,_("x or z or <Down>  page down"));
+      wcd_mvwaddstr(win, 2,0,_(", or <Left>       scroll 1 left"));
+      wcd_mvwaddstr(win, 3,0,_(". or <Right>      scroll 1 right"));
+      wcd_mvwaddstr(win, 4,0,_("< or [            scroll 10 left"));
+      wcd_mvwaddstr(win, 5,0,_("> or ]            scroll 10 right"));
+      wcd_mvwaddstr(win, 6,0,_("CTRL-a or <HOME>  scroll to beginning"));
+      wcd_mvwaddstr(win, 7,0,_("CTRL-e or <END>   scroll to end"));
+      wcd_mvwaddstr(win, 8,0,_("CTRL-c or <Esc>   abort"));
+      wcd_mvwaddstr(win, 9,0,_("<Enter>           abort"));
       wcd_mvwaddstr(win,11,0,_("Press any key."));
    }
    prefresh(win,0,0,0,0,height-1,COLS-1);
@@ -1227,13 +1241,15 @@ int display_list_curses(nameset list, WcdStack ws, int perfect,int use_numbers)
    i= WCD_ERR_LIST;
    wcd_display.number_str[n] = '\0';
 
-#ifdef __PDCURSES__
+/* Older versions of PDCurses and ncurses < 5.9.20120922 do not
+ * support newterm() on Windows */
+#if defined(__PDCURSES__) || (defined(_WIN32) && !defined(__CYGWIN__))
    initscr();
 #else
    sp = newterm(NULL,stdout,stdin);
    if (sp == NULL)
    {
-      fprintf(stderr, "%s", _("Wcd: warning: Error opening terminal, falling back to stdout interface.\n"));
+      print_error("%s", _("Error opening terminal, falling back to stdout interface.\n"));
       return WCD_ERR_CURSES;
    }
 #endif
@@ -1254,7 +1270,7 @@ int display_list_curses(nameset list, WcdStack ws, int perfect,int use_numbers)
 #ifdef XCURSES
       XCursesExit();
 #endif
-      fprintf(stderr, "%s", _("Wcd: error: screen height must be larger than 3 lines.\n"));
+      print_error("%s", _("screen height must be larger than 3 lines.\n"));
       return WCD_ERR_CURSES;
    }
 
@@ -1288,7 +1304,7 @@ int display_list_curses(nameset list, WcdStack ws, int perfect,int use_numbers)
 #ifdef XCURSES
       XCursesExit();
 #endif
-      fprintf(stderr, "%s", _("Wcd: error creating scroll window.\n"));
+      print_error("%s", _("error creating scroll window.\n"));
       return WCD_ERR_CURSES;
    }
 
@@ -1307,7 +1323,7 @@ int display_list_curses(nameset list, WcdStack ws, int perfect,int use_numbers)
 #ifdef XCURSES
       XCursesExit();
 #endif
-      fprintf(stderr, "%s", _("Wcd: error creating input window.\n"));
+      print_error("%s", _("error creating input window.\n"));
       return WCD_ERR_CURSES;
    }
 
@@ -1498,11 +1514,12 @@ int display_list_stdout(nameset list,WcdStack ws, int perfect, int use_stdout)
          return(WCD_ERR_LIST);
       else
       {
+         printf("\n");
          if(perfect)
-           printf(_("\nPerfect "));
+           printf(_("Perfect match for %d directories."),(int)list->size);
          else
-           printf(_("\nWild "));
-         printf(_("match for %lu directories.\n"),(unsigned long)list->size);
+           printf(_("Wild match for %d directories."),(int)list->size);
+         printf("\n");
          printf(_("Please choose one (<Enter> to abort): "));
       }
 
@@ -1545,7 +1562,8 @@ int display_list_stdout(nameset list,WcdStack ws, int perfect, int use_stdout)
             if ( use_stdout & WCD_STDOUT_DUMP )
               return(WCD_ERR_LIST);
 
-            printf(_("\nPlease choose one (<Enter> to abort): "));
+	    printf("\n");
+            printf(_("Please choose one (<Enter> to abort): "));
             i = wcd_get_int();
 
             if (( i <=0)||(i > (int)ws->size)) /* fail */
