@@ -39,19 +39,28 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  Modification history:
    V1.0  02-May-91,  Original version.
    V2.0  13-May-94,  Reimplemented findfirst/findnext with ffblk structure
-		     to match MS-DOS externally, fixed wildcard evaluation
-		     function.
+                     to match MS-DOS externally, fixed wildcard evaluation
+                     function.
    V2.1  08-Jun-94,  Replaced wildcard evaluation function with recursive
-		     function provided by Info-ZIP's portable UnZip,
-		     added dd_ prefix to most functions & constants,
-		     added VMS functions + MSC/TURBOC macros.
+                     function provided by Info-ZIP's portable UnZip,
+                     added dd_ prefix to most functions & constants,
+                     added VMS functions + MSC/TURBOC macros.
    V2.1a 16-Oct-96,  Call lstat() instead of stat() to avoid expanding on
-		     symbolic linked directories.
+                     symbolic linked directories.
    Jan 3 2000, Erwin Waterlander, update for Mingw32 compiler.
    Apr 29 2002, Erwin Waterlander, update for LCC windows compiler.
-   Jul 14 2008, Erwin Waterlander, update for OS2 using gcc.
+   Jul 14 2008, Erwin Waterlander, update for OS/2 using gcc.
    Jul 28 2009, Erwin Waterlander, support UTF-16 Unicode on Windows.
                 UTF-16 wide character names are converted to UTF-8 multi-byte strings.
+   Aug 2012, Major cleanup macros:
+             * Use only C99 predefined macros.
+             * Use __MSDOS__ only when it's real for MS-DOS.
+             * UNIX is not defined on OS/2 EMX (fixed tailor.h, UNIX got defined,
+               because _BSD_SOURCE is defined with EMX (GCC on OS/2)).
+             * Make it compile with Watcom C for OS/2.
+             * Borland C and LCC may have been broken, because these are not supported
+               anymore.
+        Erwin Waterlander
   */
 
 #include <string.h>
@@ -67,10 +76,6 @@ struct stat dd_sstat;  /* global stat structure of last successful file
 			*/
 #endif
 
-#ifdef OS2
-#undef UNIX
-#endif
-
 #ifdef UNIX
 #  define STAT lstat /* don't expand symbolic links */
 #else /* ?MSDOS\VMS */
@@ -81,18 +86,7 @@ struct stat dd_sstat;  /* global stat structure of last successful file
 #  endif
 #endif
 
-#if (defined (MSDOS) && !defined(OS2))
-#  ifdef __TURBOC__
-#    define FSTRUCT		struct ffblk
-#    define FATTR		FA_HIDDEN+FA_SYSTEM+FA_DIREC
-#    define FFIRST(n,d,a)	findfirst(n,d,a)
-#    define FNEXT(d)		findnext(d)
-#    define FNAME		ff_name
-#    define FATTRIB		ff_attrib
-#    define FSIZE		ff_fsize
-#    define FDATE		ff_fdate
-#    define FTIME		ff_ftime
-#  elif (defined(__MINGW32__) || defined(__LCC__))
+#if defined(_WIN32) || (defined(__OS2__) && !defined(__EMX__))
 #    define FSTRUCT		struct _finddata_t
 #    define FATTR		_A_HIDDEN+_A_SYSTEM+_A_SUBDIR
 #    ifdef WCD_UTF16
@@ -105,6 +99,17 @@ struct stat dd_sstat;  /* global stat structure of last successful file
 #    define FNAME		name
 #    define FATTRIB		attrib
 #    define FSIZE		size
+#elif defined (__MSDOS__)
+#  ifdef __TURBOC__
+#    define FSTRUCT		struct ffblk
+#    define FATTR		FA_HIDDEN+FA_SYSTEM+FA_DIREC
+#    define FFIRST(n,d,a)	findfirst(n,d,a)
+#    define FNEXT(d)		findnext(d)
+#    define FNAME		ff_name
+#    define FATTRIB		ff_attrib
+#    define FSIZE		ff_fsize
+#    define FDATE		ff_fdate
+#    define FTIME		ff_ftime
 #  else /* !__TURBOC__ */
 #    define FSTRUCT		struct find_t
 #    define FATTR		_A_HIDDEN+_A_SYSTEM+_A_SUBDIR
@@ -116,92 +121,12 @@ struct stat dd_sstat;  /* global stat structure of last successful file
 #    define FDATE		wr_date
 #    define FTIME		wr_time
 #  endif /* ?__TURBOC__ */
-#else /* ?UNIX/VMS/OS2 */
-#  include "match.h"
+#endif
 
-#  ifdef OS2
+/* Various implementations of setdisk/getdisk */
 
-/* OS2 implementation of getdisk and setdisk */
-
-/*
- * getdisk
- *
- * Returns: -1 if error, otherwise: 0=drive A, 1=drive B, and so on.
- */
-int getdisk()
-{
-	ULONG ulDrive;
-	ULONG ulLogical;
-	APIRET rc;
-
-	rc=DosQueryCurrentDisk(&ulDrive, &ulLogical); /* Get current drive */
-	int d;
-	d = (int)ulDrive;
-	return(d-1);
-}
-
-/*
- * setdisk: 0=drive A, 1=drive B, and so on.
- *
- * Returns: total number of drive available
- *
- */
-int setdisk( int drive )
-{
-	int d;
-	ULONG ulDrive;
-	ulDrive = (ULONG)(drive+1);
-	if(DosSetDefaultDisk(ulDrive)) /* Set default drive, 1=A, 2=B, 3=C, 4=D */
-	{
-		/* printf("Wcd: error: Can not change default drive to %d\n",drive); */
-		return(-1);
-	}
-
-	d = getdisk();
-	return(d);
-}
-
-#  else
-/* stub functions for get/set disk
- * fake MS-DOS functions that do not apply to unix or vms:
- */
-
-int getdisk()
-{
-  return 0;
-}
-
-int setdisk( int drive )
-{
-  return 0;
-}
-
-#  endif /* OS2 */
-#endif /* ?MSDOS */
-
-
-#if (defined (MSDOS) && !defined(OS2))
-
-#  if (defined(__MINGW32__)||defined(__LCC__))
-
-int getdisk()
-{
-	int d;
-	d = _getdrive();
-	return(d-1);
-}
-int setdisk (int drive)
-{
-	unsigned long numdrives;
-	_chdrive(drive+1);
-	numdrives = _getdrives();
-	return ((int)numdrives);
-}
-
-
-#  else
-
-#    ifndef __TURBOC__
+#if defined(__MSDOS__) || (defined(__WATCOMC__) && defined(__NT__))
+#  ifndef __TURBOC__
 /*
  * getdisk
  *
@@ -227,9 +152,82 @@ int setdisk( int drive )
    return numdrives;
 }
 
-#    endif /* ?!__TURBOC__ */
-#  endif  /* ?__MINGW32__ || __LCC__ */
+#  endif /* ?!__TURBOC__ */
 
+#elif defined(__OS2__)
+
+/* OS/2 implementation of getdisk and setdisk for EMX */
+
+/*
+ * getdisk
+ *
+ * Returns: -1 if error, otherwise: 0=drive A, 1=drive B, and so on.
+ */
+int getdisk()
+{
+	ULONG ulDrive;
+	ULONG ulLogical;
+	APIRET rc;
+	int d;
+
+	rc=DosQueryCurrentDisk(&ulDrive, &ulLogical); /* Get current drive */
+	d = (int)ulDrive;
+	return(d-1);
+}
+
+/*
+ * setdisk: 0=drive A, 1=drive B, and so on.
+ *
+ * Returns: total number of drive available
+ *
+ */
+int setdisk( int drive )
+{
+	int d;
+	ULONG ulDrive;
+	ulDrive = (ULONG)(drive+1);
+	if(DosSetDefaultDisk(ulDrive)) /* Set default drive, 1=A, 2=B, 3=C, 4=D */
+	{
+		/* printf("Wcd: error: Can not change default drive to %d\n",drive); */
+		return(-1);
+	}
+
+	d = getdisk();
+	return(d);
+}
+#elif defined(_WIN32)
+
+int getdisk(void)
+{
+	int d;
+	d = _getdrive();
+	return(d-1);
+}
+int setdisk (int drive)
+{
+	unsigned long numdrives;
+	_chdrive(drive+1);
+	numdrives = _getdrives();
+	return ((int)numdrives);
+}
+#else
+/* stub functions for get/set disk
+ * fake MS-DOS functions that do not apply to unix or vms:
+ */
+
+int getdisk()
+{
+  return 0;
+}
+
+int setdisk( int drive )
+{
+  return 0;
+}
+#endif
+
+
+#if defined(__MSDOS__) || defined(_WIN32) || (defined(__OS2__) && !defined(__EMX__))
 #  if 0
 /* function used if we want to fake stat info instead of failing the file,
  * but I cannot find a case where stat fails after findfirst/findnext succeeds.
@@ -304,11 +302,11 @@ static int dd_initstruct( dd_ffblk* fb )
   return 0;
 }
 
-# if (defined(__MINGW32__)||defined(__LCC__))
+# if defined(_WIN32) || (defined(__OS2__) && !defined(__EMX__))
 
-int dd_findnext( dd_ffblk* fb )
+wcd_intptr_t dd_findnext( dd_ffblk* fb )
 {
-    int rc;
+    wcd_intptr_t rc;
     /* repeat until file info is initialized or no more files are left */
    while ((rc=FNEXT(fb->nHandle,&fb->dos_fb)) == 0 && (rc=dd_initstruct(fb)) != 0);
    if (rc != 0) /* no more files left */
@@ -316,13 +314,13 @@ int dd_findnext( dd_ffblk* fb )
    return rc;
 }
 
-int dd_findfirst( const wcd_char *path, dd_ffblk *fb, int attrib )
+wcd_intptr_t dd_findfirst( const wcd_char *path, dd_ffblk *fb, int attrib )
 {
-   int rc;
+   wcd_intptr_t rc;
    if ((rc = FFIRST( path, &fb->dos_fb)) != -1)
    {
    fb->nHandle = rc;
-   fb->dd_attribs = attrib;
+   fb->dd_attribs = (char)attrib;
 
    if ((rc = dd_initstruct(fb)) != 0) /* initialization failed? */
             rc = dd_findnext( fb );
@@ -381,6 +379,8 @@ int dd_findfirst( const char *path, dd_ffblk *fb, int attrib )
 # endif
 #elif defined (VMS)
 
+#  include "match.h"
+
 int dd_findnext( dd_ffblk* fb )
 {
   int rc;
@@ -451,7 +451,9 @@ int dd_findfirst( const char *path, dd_ffblk *fb, int attrib )
   return dd_findnext(fb);
 }
 
-#else /* ?UNIX or OS2 */
+#else /* ?UNIX or EMX */
+
+#  include "match.h"
 
 int dd_findnext(dd_ffblk* fb)
 {
@@ -501,4 +503,4 @@ int dd_findfirst( const char *path,dd_ffblk* fb,int attrib)
   return dd_findnext(fb);
 }  /** dd_findfirst **/
 
-#endif /* ?MSDOS */
+#endif /* ?__MSDOS__ */
